@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

//@mixin recent_news--xl() {
@media #{$media_xl} {
    /* Widget: Recent News */
	.sc_recent_news_style_news-announce .post_size_medium .post_title,
	.sc_recent_news_style_news-announce .post_size_small .post_title {	font-size: 1.2em; }
	.sc_recent_news_style_news-announce .post_size_full {	height: 372px; }
	.sc_recent_news_style_news-announce .post_size_big {	height: 186px; }
	.sc_recent_news_style_news-announce .post_size_medium {	height: 93px;  }
	.sc_recent_news_style_news-announce .post_size_small {	height: 93px; }
}

//@mixin recent_news--lg() {
@media #{$media_lg} {
    /* Widget: Recent News */
	.sc_recent_news_style_news-announce .post_size_small .post_title {	margin-bottom: 0.8em; }
	.sc_recent_news_style_news-announce .post_size_small .post_meta {	display: none; }
}

//@mixin recent_news--md() {
@media #{$media_md} {
    /* Widget: Recent News */
	.sc_recent_news_style_news-announce .post_item {		float:none; }
	.sc_recent_news_style_news-announce .post_size_full {	width: 100%; height: 198px; }
	.sc_recent_news_style_news-announce .post_size_big {	width: 100%; height: 198px; }
	.sc_recent_news_style_news-announce .post_size_medium {	width: 100%; height: 198px;  }
	.sc_recent_news_style_news-announce .post_size_small {	width: 100%; height: 198px; }
	.sc_recent_news_style_news-announce .post_size_full .post_featured { max-height: 100%; }
	.sc_recent_news_style_news-announce .post_size_big .post_featured { max-height: 100%; }
	.sc_recent_news_style_news-announce .post_size_medium .post_featured { max-height: 100%; }
	.sc_recent_news_style_news-announce .post_size_small .post_featured { max-height: 100%; }

	.sc_recent_news_style_news-announce .post_size_small .post_title {	margin-bottom: 0; }
	.sc_recent_news_style_news-announce .post_size_small .post_meta {	display: block; }
}

//@mixin recent_news--sm() {
@media #{$media_sm} {
    /* Widget: Recent News */
	.sc_recent_news_style_news-announce .post_size_full {	height: 168px; }
	.sc_recent_news_style_news-announce .post_size_big {	height: 168px; }
	.sc_recent_news_style_news-announce .post_size_medium {	height: 168px;  }
	.sc_recent_news_style_news-announce .post_size_small {	height: 168px; }

	.sc_recent_news_style_news-announce .post_item .post_title {	margin-bottom: 0.8em; }
	.sc_recent_news_style_news-announce .post_item .post_meta {		display: none; }
}

//@mixin recent_news--xs() {
@media #{$media_xs} {
    /* Widget: Recent News */
	.sc_recent_news_style_news-excerpt .post_item .post_featured {
		float:none;
		padding-right:0;
		margin-bottom:1.5em;
		width: 100%;
	}
	.sc_recent_news_style_news-excerpt .post_item .post_body {
		float:none;
		width:100%;
		padding: 0;
	}
	.sc_recent_news_header_split .sc_recent_news_header_captions,
	.sc_recent_news_header_split .sc_recent_news_header_categories {
		width:100%;
		padding-right:0;
		text-align:left;
	}
	.sc_recent_news_header_split .sc_recent_news_header_categories {
		margin-top:1em;
	}
	.sc_recent_news_header_split .sc_recent_news_header_categories > * {
		margin: 0 1em 0 0;
	}
	.sc_recent_news_style_news-announce .post_size_full {	height: 112px; }
	.sc_recent_news_style_news-announce .post_size_big {	height: 112px; }
	.sc_recent_news_style_news-announce .post_size_medium {	height: 112px;  }
	.sc_recent_news_style_news-announce .post_size_small {	height: 112px; }
}